DeltaBuffer

Struct DeltaBuffer 

pub struct DeltaBuffer<D: Lattice> { /* private fields */ }
Buffer for outgoing deltas with grouping support

Implementations

Source

impl<D: Lattice> DeltaBuffer<D>

pub fn new(max_buffer_size: usize) -> Self

pub fn push(&mut self, delta: D)

Add a new delta to the buffer

pub fn deltas_since(&self, acked_seq: SeqNo) -> Vec<&TaggedDelta<D>>

Get deltas for sending to a peer that has acked up to acked_seq

pub fn delta_group_since(&self, acked_seq: SeqNo) -> Option<D>

Create a delta-group (joined deltas) for a peer

pub fn ack(&mut self, acked_seq: SeqNo) -> usize

Acknowledge that a peer has received up to seq Deltas before this can be GC’d if all peers have acked

pub fn current_seq(&self) -> SeqNo

Current sequence number

pub fn len(&self) -> usize

Number of buffered deltas

pub fn is_empty(&self) -> bool

Check if buffer is empty

pub fn clear(&mut self)

Clear all buffered deltas