pub struct DeltaBuffer<D: Lattice> { /* private fields */ }Expand description
Buffer for outgoing deltas with grouping support
Implementations
Sourceimpl<D: Lattice> DeltaBuffer<D>
impl<D: Lattice> DeltaBuffer<D>
pub fn new(max_buffer_size: usize) -> Self
Sourcepub fn deltas_since(&self, acked_seq: SeqNo) -> Vec<&TaggedDelta<D>>
pub fn deltas_since(&self, acked_seq: SeqNo) -> Vec<&TaggedDelta<D>>
Get deltas for sending to a peer that has acked up to acked_seq
Sourcepub fn delta_group_since(&self, acked_seq: SeqNo) -> Option<D>
pub fn delta_group_since(&self, acked_seq: SeqNo) -> Option<D>
Create a delta-group (joined deltas) for a peer
Sourcepub fn ack(&mut self, acked_seq: SeqNo) -> usize
pub fn ack(&mut self, acked_seq: SeqNo) -> usize
Acknowledge that a peer has received up to seq
Deltas before this can be GC’d if all peers have acked
Sourcepub fn current_seq(&self) -> SeqNo
pub fn current_seq(&self) -> SeqNo
Current sequence number